==> bycon-1.4.1-py3-none-any.whl: bycon/lib/args_parsing.py <==
import argparse
import re
from humps import camelize, decamelize

from bycon_helpers import prdbug

################################################################################

def get_bycon_args(byc):
    if byc.get("check_args", True) is False:
        return

    # Serves as "we've been here before" marker - before the env check.
    byc.update({"check_args": False})

    create_args_parser(byc)


################################################################################

def create_args_parser(byc):
    if not "local" in byc.get("env", "server"):
        return

    a_defs = byc.get("argument_definitions")
    parser = argparse.ArgumentParser()
    for a_n, a_d in a_defs.items():
        if "cmdFlags" in a_d:
            argDef = {
                "flags": a_d.get("cmdFlags"),
                "help": a_d.get("description", "TBD"),
            }
            default = a_d.get("default")
            if default:
                argDef.update({"default": default})
            parser.add_argument(*argDef.pop("flags"), **argDef)

    byc.update({"args": parser.parse_args()})


################################################################################

def args_update_form(byc):
    """
    This function adds comand line arguments to the `byc["form_data"]` input
    parameter collection (in "local" context).
    """
    if not "args" in byc:
        return
    if not "local" in byc.get("env", "server"):
        return

    a_defs = byc["argument_definitions"]
    list_pars = []
    for a_n, a_d in a_defs.items():
        if "cmdFlags" in a_d:
            a_d_k = camelize(a_n)
            if "array" in a_d.get("type", "string"):
                list_pars.append(a_d_k)

    arg_vars = vars(byc["args"])

    for p in arg_vars.keys():
        if arg_vars[p] is None:
            continue
        p_d = decamelize(p)
        if p in list_pars:
            byc["form_data"].update({p_d: arg_vars[p].split(',')})
        else:
            byc["form_data"].update({p_d: arg_vars[p]})
        prdbug(f'{p}: {byc["form_data"][p_d]}', byc.get("debug_mode"))

==> bycon-1.5.1-py3-none-any.whl: bycon/lib/args_parsing.py <==
import argparse, humps, re

from bycon_helpers import prdbug, set_debug_state
from config import *

################################################################################

def args_update_form(byc):
    """
    This function adds comand line arguments to the `BYC_PARS` input
    parameter collection (in "local" context).
    """
    # Serves as "we've been here before" marker - before the env check.
    if byc.get("check_args", True) is False:
        return
    byc.update({"check_args": False})

    a_defs = byc["argument_definitions"]
    cmd_args = create_args_parser(a_defs)
    list_pars = []
    for a_n, a_d in a_defs.items():
        if "cmdFlags" in a_d:
            a_d_k = humps.camelize(a_n)
            if "array" in a_d.get("type", "string"):
                list_pars.append(a_d_k)
    arg_vars = vars(cmd_args)
    for p in arg_vars.keys():
        if not arg_vars[p]:
            continue
        p_d = humps.decamelize(p)
        if p in list_pars:
            BYC_PARS.update({p_d: arg_vars[p].split(',')})
        else:
            BYC_PARS.update({p_d: arg_vars[p]})

    BYC.update({"DEBUG_MODE": set_debug_state(BYC_PARS.get("debug_mode", False)) })


################################################################################

def create_args_parser(a_defs):
    parser = argparse.ArgumentParser()
    for a_n, a_d in a_defs.items():
        if "cmdFlags" in a_d:
            argDef = {
                "flags": a_d.get("cmdFlags"),
                "help": a_d.get("description", "TBD"),
            }
            default = a_d.get("default")
            if default:
                argDef.update({"default": default})
            parser.add_argument(*argDef.pop("flags"), **argDef)
    cmd_args = parser.parse_args()
    return cmd_args
